from pydantic import (
    BaseConfig as PydanticBaseConfig,
    BaseModel as PydanticBaseModel,
)

try:
    import ujson as json
except ImportError:
    import json

__all__ = ['Model']


class Model(PydanticBaseModel):
    """基类"""

    def __new__(cls, *args, **kwargs):
        cls.update_forward_refs()
        return super(Model, cls).__new__(cls)

    class Config(PydanticBaseConfig):
        # 使用 ujson 作为解析库
        json_dumps = json.dumps
        json_loads = json.loads



from typing import (
    NoReturn,
    Optional,
)
from typing_extensions import Self

from aiohttp import ClientSession

try:
    import ujson as json
except ImportError:
    import json


class Enka(object):
    _client: Optional[ClientSession] = None

    async def __aenter__(self) -> Self:
        if self._client is None:
            self._client = ClientSession(json_serialize=json.dumps)
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb) -> NoReturn:
        if not (self._client is None or self._client.closed):
            await self._client.close()

    async def fetch(self, uid: int):
        ...



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['enka', 'enka.model']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8.1,<4.0.0', 'pydantic>=1.9.2,<2.0.0']

setup_kwargs = {
    'name': 'py-enka',
    'version': '0.0.1',
    'description': '',
    'long_description': '# Py-Enka\n\n用于 Python 的 [Enka.Network](https://enka.network) API',
    'author': 'Arko',
    'author_email': 'arko.space.cc@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ArkoClub/py-enka',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
